@@ -117,7 +117,8 @@ getsecret(void *context __attribute__((unused)),
   }
   db = dbm_open(path, O_RDONLY, S_IRUSR | S_IWUSR);
   if (! db) {
-    return SASL_FAIL;
+	result = SASL_FAIL;
+	goto cleanup;
   }
   dkey.dptr = key;
   dkey.dsize = key_len;
@@ -147,7 +148,8 @@ getsecret(void *context __attribute__((unused)),
 
  cleanup:
   sasl_FREE(key);
-  dbm_close(db);
+  if (db)
+    dbm_close(db);
 
   return result;
 }
