@@ -45,6 +45,7 @@
 #include <stdio.h>
 #include <time.h>
 #include <stdlib.h>
+#include <string.h>
 #include <assert.h>
 #ifdef HAVE_GETTIMEOFDAY
 #include <sys/time.h>
@@ -358,6 +359,13 @@ static void randinit(sasl_rand_t *rpool)
     if (!rpool->initialized) {
 	getranddata(rpool->pool);
 	rpool->initialized = 1;
+
+#ifdef __APPLE__
+    {
+	long *foo = (long *)rpool->pool;
+	srandom(*foo);
+    }
+#endif
     }
 }
 
@@ -369,14 +377,19 @@ void sasl_rand (sasl_rand_t *rpool, char *buf, unsigned len)
     
     /* init if necessary */
     randinit(rpool);
-    
-#ifdef WIN32
+
+#ifdef __APPLE__
+    for (lup=0;lup<len;lup++)
+	buf[lup] = (char) (random() >> 8);
+#else
+#if (defined(WIN32)||defined(macintosh))
     for (lup=0;lup<len;lup++)
 	buf[lup] = (char) (rand() >> 8);
 #else /* WIN32 */
     for (lup=0; lup<len; lup++)
 	buf[lup] = (char) (jrand48(rpool->pool) >> 8);
 #endif /* WIN32 */
+#endif
 }
 
 /* this function is just a bad idea all around, since we're not trying to
