@@ -1,6 +1,6 @@
 /* SASL server API implementation
  * Tim Martin
- * $Id: server.c,v 1.84 2001/02/06 20:54:28 leg Exp $
+ * $Id: server.c,v 1.88 2001/06/20 11:47:24 n3liw Exp $
  */
 
 /* 
@@ -50,8 +50,10 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <limits.h>
+#ifndef macintosh
 #include <sys/types.h>
 #include <sys/stat.h>
+#endif
 #include <fcntl.h>
 #include <string.h>
 #include <ctype.h>
@@ -296,8 +298,6 @@ int sasl_setpass(sasl_conn_t *conn,
     int result=SASL_OK, tmpresult;
     sasl_server_conn_t *s_conn = (sasl_server_conn_t *) conn;
     mechanism_t *m;
-    sasl_getopt_t *getopt;
-    void *context;
      
     /* check params */
     if (errstr) { *errstr = NULL; }
@@ -613,7 +613,7 @@ static int verify_server_callbacks(const sasl_callback_t *callbacks)
     return SASL_OK;
 }
 
-char *grab_field(char *line, char **eofield)
+static char *grab_field(char *line, char **eofield)
 {
     int d = 0;
     char *field;
@@ -776,8 +776,7 @@ int sasl_server_init(const sasl_callback_t *callbacks,
     /* delayed loading of plugins? */
     if (_sasl_getcallback(NULL, SASL_CB_GETOPT, &getopt, &context) 
 	   == SASL_OK) {
-	getopt((void *) &global_callbacks, NULL, 
-	       "plugin_list", &pluginfile, NULL);
+	getopt(context, NULL, "plugin_list", &pluginfile, NULL);
     }
     if (pluginfile != NULL) {
 	/* this file should contain a list of plugins available.
