@@ -46,10 +46,15 @@
 #include <saslplug.h>
 
 #include <stdio.h>
+#include <string.h> 
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
 
+#ifdef macintosh 
+#include <sasl_anonymous_plugin_decl.h> 
+#endif 
+
 #ifdef WIN32
 /* This must be after sasl.h, saslutil.h */
 # include "saslANONYMOUS.h"
@@ -122,6 +127,9 @@ server_continue_step (void *conn_context __attribute__((unused)),
     return SASL_CONTINUE;
   }
 
+  /* We force a truncation 255 characters (specified by RFC 2245) */
+  if (clientinlen > 255) clientinlen = 255;
+
   /* NULL-terminate the clientin... */
   clientdata = sparams->utils->malloc(clientinlen + 1);
   if (! clientdata)
@@ -385,7 +393,7 @@ client_continue_step(void *conn_context,
   oparams->realm=NULL;
   oparams->param_version=0;
 
-  text->state = 2;
+  text->state = 3;
 
   return SASL_CONTINUE;
 }
