@@ -1,6 +1,6 @@
 /* CRAM-MD5 SASL plugin
  * Tim Martin 
- * $Id: cram.c,v 1.55 2001/02/19 19:01:54 leg Exp $
+ * $Id: cram.c,v 1.58.2.1 2002/07/16 18:58:56 rjs3 Exp $
  */
 
 /* 
@@ -43,22 +43,24 @@
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
 
-#ifdef HAVE_CONFIG_H
+#include <string.h>
+#include <stdlib.h>
+#include <stdio.h>
 #include <config.h>
-#endif /* HAVE_CONFIG_H */
-#ifdef WIN32
-/* # include "winconfig.h" */
-#include <config.h>
-#include <stdio.h>		/* for sprintf, snprinft */
-#endif /* WIN32 */
 #include <time.h>
+#ifndef macintosh
 #include <sys/stat.h>
+#endif
 #include <fcntl.h>
 #include <sasl.h>
 #include <saslplug.h>
 #include <saslutil.h>
 #include <assert.h>
 
+#ifdef macintosh
+#include <sasl_cram_plugin_decl.h>
+#endif
+
 #ifdef WIN32
 /* This must be after sasl.h, saslutil.h */
 # include "saslCRAM.h"
@@ -309,15 +311,13 @@ static char *convert16(unsigned char *in, int inlen, sasl_utils_t *utils)
 }
 
 static char *make_hashed(sasl_secret_t *sec, char *nonce, int noncelen, 
-			 void *inparams)
+			 sasl_utils_t *utils)
 {
   char secret[65];
   unsigned char digest[24];  
   int lup;
   char *in16;
 
-  sasl_server_params_t *params=(sasl_server_params_t *) inparams;
-
   if (sec==NULL) return NULL;
 
   if (sec->len<64)
@@ -336,11 +336,11 @@ static char *make_hashed(sasl_secret_t *sec, char *nonce, int noncelen,
   VL(("nonce=[%s] %i\n",nonce, noncelen));
 
   /* do the hmac md5 hash output 128 bits */
-  params->utils->hmac_md5((unsigned char *) nonce,noncelen,
-			  (unsigned char *) secret,64,digest);
+  utils->hmac_md5((unsigned char *) nonce,noncelen,
+		  (unsigned char *) secret,64,digest);
 
   /* convert that to hex form */
-  in16=convert16(digest,16,params->utils);
+  in16=convert16(digest,16,utils);
   if (in16==NULL) return NULL;
 
   return in16;
@@ -503,7 +503,7 @@ static int server_continue_step (void *conn_context,
     sparams->utils->hmac_md5_final((unsigned char *)&digest, &tmphmac);
 
     /* convert to base 16 with lower case letters */
-    digest_str = convert16((unsigned char *) digest, 4, sparams->utils);
+    digest_str = convert16((unsigned char *) digest, 16, sparams->utils);
 
     /* if same then verified 
      *  - we know digest_str is null terminated but clientin might not be
@@ -1155,7 +1155,8 @@ static int c_continue_step (void *conn_context,
      * digest (keyed md5 where key is passwd)
      */
 
-    in16=make_hashed(text->password,(char *) serverin, serverinlen, params);
+    in16=make_hashed(text->password,(char *) serverin, serverinlen,
+		     params->utils);
 
     if (in16==NULL) return SASL_FAIL;
 
