@@ -71,6 +71,12 @@
 #include <saslutil.h>
 #include <saslplug.h>
 
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
+
+#include <errno.h>
+
 #ifdef WIN32
 /* This must be after sasl.h */
 # include "saslgssapi.h"
@@ -599,6 +605,8 @@ sasl_gss_server_step (void *conn_context,
 	gss_buffer_desc name_token;
 	gss_buffer_desc name_without_realm;
 	gss_name_t without = NULL;
+	char *at;
+	int nlen;
 	int equal;
 
 	name_token.value = NULL;
@@ -633,17 +641,18 @@ sasl_gss_server_step (void *conn_context,
 	   without the realm and see if it's the same id (i.e. 
 	   tmartin == tmartin@ANDREW.CMU.EDU. If this is the case we just want
 	   to return the id (i.e. just "tmartin: */
-	if (strchr((char *)name_token.value, (int) '@')!=NULL)
+	if ((at=strchr((char *)name_token.value, (int) '@'))!=NULL)
 	{
-	    name_without_realm.value = (char *) params->utils->malloc(strlen(name_token.value)+1);
+	    nlen = at - (char *)name_token.value;
+	    name_without_realm.value = (char *)params->utils->malloc(nlen+1);
 	    if (name_without_realm.value == NULL) return SASL_NOMEM;
 
-	    strcpy(name_without_realm.value, name_token.value);
+	    strncpy(name_without_realm.value, name_token.value, nlen);
 
 	    /* cut off string at '@' */
-	    (strchr(name_without_realm.value,'@'))[0] = '\0';
+	    ((char *)name_without_realm.value)[nlen] = '\0';
 
-	    name_without_realm.length = strlen( (char *) name_without_realm.value );
+	    name_without_realm.length = nlen;
 
 	    maj_stat = gss_import_name (&min_stat,
 					&name_without_realm,
@@ -686,19 +695,31 @@ sasl_gss_server_step (void *conn_context,
 
 	if (equal == 1) /* xxx True doesn't seem to exist in gssapi.h */
 	{
-	    oparams->authid = (char *) params->utils->malloc(strlen(name_without_realm.value)+1);
+	    oparams->authid = 
+		(char *)params->utils->malloc(name_without_realm.length+1);
 	    if (oparams->authid == NULL) return SASL_NOMEM;
 	    strcpy(oparams->authid, name_without_realm.value);
 	} else {
-	    oparams->authid = (char *) params->utils->malloc(strlen(name_token.value)+1);
+	    oparams->authid =
+		(char *)params->utils->malloc(strlen(name_token.value)+1);
 	    if (oparams->authid == NULL) return SASL_NOMEM;
 	    strcpy(oparams->authid, name_token.value);
 	}
 
+	if (at)
+	{
+	    oparams->realm =
+		(char *)params->utils->malloc(name_token.length -
+					      name_without_realm.length);
+	    if (oparams->realm == NULL) return SASL_NOMEM;
+	    strcpy(oparams->realm, at+1);
+	}
+	
+
 	if (name_token.value)
-	    params->utils->free(name_token.value);
+	    params->utils->free(name_without_realm.value);
 	if (name_without_realm.value)
-	    gss_release_buffer(&min_stat, &name_without_realm);
+	    gss_release_buffer(&min_stat, &name_token);
 	
 	/* we have to decide what sort of encryption/integrity/etc.,
 	   we support */
@@ -887,6 +908,7 @@ sasl_server_plug_init(sasl_utils_t *utils __attribute__((unused)),
 {
 #ifdef HAVE_GSSKRB5_REGISTER_ACCEPTOR_IDENTITY
     const char *keytab;
+    char keytab_path[1024];
     unsigned int rl;
 #endif
 
@@ -906,7 +928,9 @@ sasl_server_plug_init(sasl_utils_t *utils __attribute__((unused)),
 	    return SASL_FAIL;
 	}
 
-	gsskrb5_register_acceptor_identity(keytab);
+	strncpy(keytab_path, keytab, 1024);
+	
+	gsskrb5_register_acceptor_identity(keytab_path);
     }
 #endif
 
