@@ -1,6 +1,6 @@
 /* Kerberos4 SASL plugin
  * Tim Martin 
- * $Id: kerberos4.c,v 1.65 2001/02/19 19:01:54 leg Exp $
+ * $Id: kerberos4.c,v 1.69 2001/08/03 22:06:28 rbraun Exp $
  */
 /* 
  * Copyright (c) 2000 Carnegie Mellon University.  All rights reserved.
@@ -43,10 +43,14 @@
  */
 
 #include <config.h>
+#include <stdlib.h>
+#include <string.h>
 #include <krb.h>
 #include <des.h>
 #ifdef WIN32
 # include <winsock.h>
+#elif defined(macintosh)
+#include <kcglue_krb.h>
 #else
 # include <sys/param.h>
 # include <sys/socket.h>
@@ -64,6 +68,14 @@
 
 #include <errno.h>
 
+#ifdef macintosh
+/*
+ * krb.h doenst include some functions and mac compiler is picky about declartions\
+ */
+#include <extra_krb.h>
+#include <sasl_kerberos4_plugin_decl.h>
+#endif
+
 #ifdef WIN32
 /* This must be after sasl.h, saslutil.h */
 # include "saslKERBEROSV4.h"
@@ -106,6 +118,10 @@ extern int gethostname(char *, int);
 #define KRB_DES_SECURITY_BITS (56)
 #define KRB_INTEGRITY_BITS (1)
 
+#ifndef KEYFILE
+#define KEYFILE "/etc/srvtab"
+#endif
+
 typedef struct context {
   int state;
 
@@ -188,7 +204,7 @@ static int privacy_decode(void *context,
 {
     int len, tocopy;
     unsigned diff;
-    MSG_DAT *data;
+    MSG_DAT data;
     context_t *text=context;
     char *extra;
     unsigned int extralen=0;
@@ -250,12 +266,10 @@ static int privacy_decode(void *context,
 	inputlen-=diff;
     }
     
-    data=text->malloc(sizeof(MSG_DAT));
-    if (data==NULL) return SASL_NOMEM;
-    memset(data,0,sizeof(MSG_DAT));
+    memset(&data,0,sizeof(MSG_DAT));
     
     len= krb_rd_priv((char *) text->buffer,text->size,  text->init_keysched, 
-		     &text->session, text->ip_remote, text->ip_local, data);
+		     &text->session, text->ip_remote, text->ip_local, &data);
 
     /* see if the krb library gave us a failure */
     if (len != 0) {
@@ -263,27 +277,26 @@ static int privacy_decode(void *context,
     }
 
     /* check to make sure the timestamps are ok */
-    if ((data->time_sec < text->time_sec) || /* if an earlier time */
-	(((data->time_sec == text->time_sec) && /* or the exact same time */
-	 (data->time_5ms < text->time_5ms)))) 
+    if ((data.time_sec < text->time_sec) || /* if an earlier time */
+	(((data.time_sec == text->time_sec) && /* or the exact same time */
+	 (data.time_5ms < text->time_5ms)))) 
     {
       return SASL_FAIL;
     }
-    text->time_sec = data->time_sec;
-    text->time_5ms = data->time_5ms;
+    text->time_sec = data.time_sec;
+    text->time_5ms = data.time_5ms;
 
 
 
-    *output = text->malloc(data->app_length + 1);
+    *output = text->malloc(data.app_length + 1);
     if ((*output) == NULL) {
 	return SASL_NOMEM;
     }
     
-    *outputlen = data->app_length;
-    memcpy(*output, data->app_data, data->app_length);
+    *outputlen = data.app_length;
+    memcpy(*output, data.app_data, data.app_length);
     (*output)[*outputlen] = '\0';
 
-    text->free(data);
     text->size = -1;
     text->needsize = 4;
 
@@ -339,7 +352,7 @@ static int integrity_decode(void *context, const char *input, unsigned inputlen,
 		  char **output, unsigned *outputlen)
 {
     int len, tocopy;
-    MSG_DAT *data;
+    MSG_DAT data;
     context_t *text=context;
     char *extra;
     unsigned int extralen=0;
@@ -401,12 +414,9 @@ static int integrity_decode(void *context, const char *input, unsigned inputlen,
       inputlen-=diff;
     }
   
-    data=text->malloc(sizeof(MSG_DAT));
-    if (data==NULL) return SASL_NOMEM;
-
     len= krb_rd_safe((char *) text->buffer,text->size, /* text->keysched, */
 		     &text->session,
-		     text->ip_remote, text->ip_local, data);
+		     text->ip_remote, text->ip_local, &data);
 
 
     /* see if the krb library found a problem with what we were given */
@@ -416,23 +426,22 @@ static int integrity_decode(void *context, const char *input, unsigned inputlen,
     }
 
     /* check to make sure the timestamps are ok */
-    if ((data->time_sec < text->time_sec) || /* if an earlier time */
-	(((data->time_sec == text->time_sec) && /* or the exact same time */
-	 (data->time_5ms < text->time_5ms)))) 
+    if ((data.time_sec < text->time_sec) || /* if an earlier time */
+	(((data.time_sec == text->time_sec) && /* or the exact same time */
+	 (data.time_5ms < text->time_5ms)))) 
     {
       return SASL_FAIL;
     }
-    text->time_sec = data->time_sec;
-    text->time_5ms = data->time_5ms;
+    text->time_sec = data.time_sec;
+    text->time_5ms = data.time_5ms;
 
 
-    *output=text->malloc(data->app_length+1);
+    *output=text->malloc(data.app_length+1);
     if ((*output) == NULL) return SASL_NOMEM;
  
-    *outputlen=data->app_length;
-    memcpy((char *)*output, data->app_data,data->app_length);
+    *outputlen=data.app_length;
+    memcpy((char *)*output, data.app_data,data.app_length);
 
-    text->free(data);
     text->size=-1;
     text->needsize=4;
 
@@ -476,6 +485,7 @@ new_text(sasl_utils_t *utils, context_t **text)
     return SASL_OK;
 }
 
+#ifndef macintosh
 static int
 server_start(void *glob_context __attribute__((unused)),
 	     sasl_server_params_t *sparams,
@@ -489,8 +499,7 @@ server_start(void *glob_context __attribute__((unused)),
 
   return new_text(sparams->utils, (context_t **) conn);
 }
-
-
+#endif
 
 static void dispose(void *conn_context, sasl_utils_t *utils)
 {
@@ -532,6 +541,7 @@ static int cando_sec(sasl_security_properties_t *props,
   return 0;
 }
 
+#ifndef macintosh
 static int server_continue_step (void *conn_context,
 	      sasl_server_params_t *sparams,
 	      const char *clientin,
@@ -627,7 +637,7 @@ static int server_continue_step (void *conn_context,
 	VL(("krb_rd_req failed service=%s instance=%s error code=%i\n",
 	    sparams->service, text->instance,result));
 	if (errstr)
-	    *errstr = krb_err_txt[result];
+	    *errstr = get_krb_err_txt(result);
 	return SASL_BADAUTH;
     }
 
@@ -849,6 +859,7 @@ static const sasl_server_plug_t plugins[] =
     NULL
   }
 };
+#endif
 
 int sasl_server_plug_init(sasl_utils_t *utils,
 			  int maxversion,
@@ -856,6 +867,9 @@ int sasl_server_plug_init(sasl_utils_t *utils,
 			  const sasl_server_plug_t **pluglist,
 			  int *plugcount)
 {
+#ifdef macintosh
+	return SASL_BADVERS;
+#else
     const char *ret;
     unsigned int rl;
     
@@ -866,7 +880,7 @@ int sasl_server_plug_init(sasl_utils_t *utils,
     utils->getopt(utils->getopt_context, "KERBEROS_V4", "srvtab", &ret, &rl);
 
     if (ret == NULL) {
-	ret = KEYFILE;
+	ret = "/etc/srvtab";
 	rl = strlen(ret);
     }
     srvtab = utils->malloc(sizeof(char) * (rl + 1));
@@ -885,6 +899,7 @@ int sasl_server_plug_init(sasl_utils_t *utils,
     *out_version = KERBEROS_VERSION;
     
     return SASL_OK;
+#endif
 }
 
 static int client_start(void *glob_context __attribute__((unused)), 
@@ -984,13 +999,27 @@ static int client_continue_step (void *conn_context,
 	/* text->instance is NULL terminated unless it was too long */
 	text->instance[sizeof(text->instance)-1] = '\0';
 
+#ifdef macintosh
+	memset(&text->credentials,0,sizeof(text->credentials));
+    result=kcglue_krb_mk_req(ticket.dat,
+    		   &ticket.length,
+    		   params->service,
+    		   text->instance,
+			   text->realm,
+			   text->challenge,
+			   &text->credentials.session,
+			   text->credentials.pname,
+			   text->credentials.pinst);
+	if(result!=0)
+#else
 	if ((result=krb_mk_req(&ticket, (char *) params->service, 
 			       text->instance, text->realm,text->challenge)))
+#endif
 	{
 	    params->utils->log(NULL, SASL_LOG_ERR, "KERBEROS_V4", 
 			       SASL_FAIL, 0, 
 			       "krb_mk_req() failed: %s (%d)",
-			       krb_err_txt[result], result);
+			       get_krb_err_txt(result), result);
 	    return SASL_FAIL;
 	}
     
@@ -1105,6 +1134,7 @@ static int client_continue_step (void *conn_context,
 
 	memcpy(in, serverin, 8);
 
+#ifndef macintosh
 	/* get credentials */
 	if ((result = krb_get_cred((char *)params->service,
 			  text->instance,
@@ -1113,10 +1143,10 @@ static int client_continue_step (void *conn_context,
 	    params->utils->log(NULL, SASL_LOG_ERR, "KERBEROS_V4", 
 			       SASL_BADAUTH, 0, 
 			       "krb_get_cred() failed: %s (%d)",
-			       krb_err_txt[result], result);
+			       get_krb_err_txt(result), result);
 	    return SASL_BADAUTH;
 	}
-
+#endif
 	memcpy(text->session, text->credentials.session, 8);
 
 	/* make key schedule for encryption and decryption */
