@@ -1,42 +1,51 @@
 /* Login SASL plugin
  * contributed by Rainer Schoepf <schoepf@uni-mainz.de>
  * based on PLAIN, by Tim Martin <tmartin@andrew.cmu.edu>
- * $Id: login.c,v 1.1 2000/01/02 04:34:53 leg Exp $
+ * $Id: login.c,v 1.7 2001/06/19 15:35:30 rjs3 Exp $
+ */
+/* 
+ * Copyright (c) 2000 Carnegie Mellon University.  All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ *
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer. 
+ *
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in
+ *    the documentation and/or other materials provided with the
+ *    distribution.
+ *
+ * 3. The name "Carnegie Mellon University" must not be used to
+ *    endorse or promote products derived from this software without
+ *    prior written permission. For permission or any other legal
+ *    details, please contact  
+ *      Office of Technology Transfer
+ *      Carnegie Mellon University
+ *      5000 Forbes Avenue
+ *      Pittsburgh, PA  15213-3890
+ *      (412) 268-4387, fax: (412) 268-7395
+ *      tech-transfer@andrew.cmu.edu
+ *
+ * 4. Redistributions of any form whatsoever must retain the following
+ *    acknowledgment:
+ *    "This product includes software developed by Computing Services
+ *     at Carnegie Mellon University (http://www.cmu.edu/computing/)."
+ *
+ * CARNEGIE MELLON UNIVERSITY DISCLAIMS ALL WARRANTIES WITH REGARD TO
+ * THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
+ * AND FITNESS, IN NO EVENT SHALL CARNEGIE MELLON UNIVERSITY BE LIABLE
+ * FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
+ * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
+ * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
+ * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
-/***********************************************************
-        Copyright 1998 by Carnegie Mellon University
-
-                      All Rights Reserved
-
-Permission to use, copy, modify, and distribute this software and its
-documentation for any purpose and without fee is hereby granted,
-provided that the above copyright notice appear in all copies and that
-both that copyright notice and this permission notice appear in
-supporting documentation, and that the name of CMU not be
-used in advertising or publicity pertaining to distribution of the
-software without specific, written prior permission.
-
-CMU DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING
-ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL
-CMU BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR
-ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
-WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
-ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
-SOFTWARE.
-******************************************************************/
 
 #include <config.h>
 #include <stdio.h>
 #include <ctype.h>
-#ifndef SASL_MINIMAL_SERVER
-#include <pwd.h>
-#endif /* SASL_MINIMAL_SERVER */
-#ifdef HAVE_CRYPT_H
-#include <crypt.h>
-#endif /* HAVE_CRYPT_H */
-#ifdef HAVE_SHADOW_H
-#include <shadow.h>
-#endif /* HAVE_SHADOW_H */
 #include <sasl.h>
 #include <saslplug.h>
 
@@ -79,6 +88,7 @@ static int start(void *glob_context __attribute__((unused)),
   text->state=1;
 
   text->username = NULL;
+  text->password = NULL;
 
   *conn=text;
 
@@ -127,26 +137,10 @@ static void mech_free(void *global_context, sasl_utils_t *utils)
   utils->free(global_context);  
 }
 
-#ifdef SASL_MINIMAL_SERVER
-
-static int server_continue_step (void *conn_context,
-	      sasl_server_params_t *params,
-	      const char *clientin,
-	      int clientinlen,
-	      char **serverout,
-	      int *serveroutlen,
-	      sasl_out_params_t *oparams,
-	      const char **errstr)
-{
-  return SASL_FAIL;
-}
-
-#else /* SASL_MINIMAL_SERVER */
-
 /* fills in password; remember to free password and wipe it out correctly */
 static
 int verify_password(sasl_server_params_t *params, 
-		    const char *user, const char *pass)
+		    const char *user, const char *pass, const char **errstr)
 {
     const char *mech;
     int result;
@@ -154,20 +148,10 @@ int verify_password(sasl_server_params_t *params,
     params->utils->getopt(params->utils->getopt_context, "LOGIN",
 			  "pwcheck_method", &mech, NULL);
 
-    if (mech == NULL) {
-#ifdef HAVE_PAM
-	mech = "PAM";
-#else
-#ifdef HAVE_KRB
-	mech = "kerberos_v4";
-#else
-	mech = "passwd";
-#endif /* HAVE_KRB */
-#endif /* HAVE_PAM */
-    }
-
+    /* if it's null, checkpass will default */
     result = params->utils->checkpass(params->utils->conn,
-				      mech, params->service, user, pass);
+				      mech, params->service, 
+				      user, pass, errstr);
     
     return result;
 }
@@ -185,8 +169,7 @@ server_continue_step (void *conn_context,
   context_t *text;
   text=conn_context;
 
-  if (errstr)
-    *errstr = NULL;
+  if (errstr) { *errstr = NULL; }
 
   oparams->mech_ssf=0;
 
@@ -206,18 +189,25 @@ server_continue_step (void *conn_context,
   VL (("Login: server state #%i\n",text->state));
 
   if (text->state == 1) {
-    /* get username */
 
-    VL (("out=%s len=%i\n",USERNAME,strlen(USERNAME)));
-
-    *serveroutlen = strlen(USERNAME);
-    *serverout = params->utils->malloc(*serveroutlen);
-    if (! *serverout) return SASL_NOMEM;
-    memcpy(*serverout,USERNAME,*serveroutlen);
-
-    text->state = 2;
-
-    return SASL_CONTINUE;
+      /* Check inlen, possibly we have already the user name */
+      /* In this case fall through to state 2 */
+      if (clientinlen > 0) {
+	  text->state = 2;
+      } else {
+	  /* get username */
+	  
+	  VL (("out=%s len=%i\n",USERNAME,strlen(USERNAME)));
+  
+	  *serveroutlen = strlen(USERNAME);
+	  *serverout = params->utils->malloc(*serveroutlen);
+	  if (! *serverout) return SASL_NOMEM;
+	  memcpy(*serverout,USERNAME,*serveroutlen);
+	  
+	  text->state = 2;
+	  
+	  return SASL_CONTINUE;
+      }
   }
 
   if (text->state == 2) {
@@ -276,7 +266,7 @@ server_continue_step (void *conn_context,
     /* verify_password - return sasl_ok on success */
 
     VL (("Verifying password...\n"));
-    result = verify_password(params, text->username->data, password);
+    result = verify_password(params, text->username->data, password, errstr);
 
     if (result != SASL_OK)
       return result;
@@ -311,6 +301,8 @@ server_continue_step (void *conn_context,
     (*serverout)[0] = '\0';
     *serveroutlen = 0;
 
+    oparams->doneflag = 1;
+
     text->state++; /* so fails if called again */
 
     return SASL_OK;
@@ -318,7 +310,6 @@ server_continue_step (void *conn_context,
 
   return SASL_FAIL; /* should never get here */
 }
-#endif /* SASL_MINIMAL_SERVER */
 
 static const sasl_server_plug_t plugins[] = 
 {
@@ -716,10 +707,13 @@ static int client_continue_step (void *conn_context,
 
     VL (("Got username, authid, and password\n"));
 
-    *clientout = params->utils->malloc(1);
-    if (! *clientout) return SASL_NOMEM;
-    (*clientout)[0] = '\0';
-    *clientoutlen = 0;
+    if (clientout) {
+	/* watch out for no initial client-send */
+	*clientout = params->utils->malloc(1);
+	if (! *clientout) return SASL_NOMEM;
+	(*clientout)[0] = '\0';
+	*clientoutlen = 0;
+    }
 
     /* set oparams */
     oparams->mech_ssf=0;
@@ -762,6 +756,8 @@ static int client_continue_step (void *conn_context,
       return SASL_BADPROT;
     }
 
+    params->utils->free(in);
+
     *clientoutlen = strlen(oparams->user);
 
     *clientout = params->utils->malloc(*clientoutlen);
@@ -788,6 +784,8 @@ static int client_continue_step (void *conn_context,
       return SASL_BADPROT;
     }
 
+    params->utils->free(in);
+
     *clientoutlen = text->password->len;
 
     *clientout = params->utils->malloc(*clientoutlen);
@@ -795,10 +793,6 @@ static int client_continue_step (void *conn_context,
     memcpy(*clientout, text->password->data, *clientoutlen);
 
     /* set oparams */
-    oparams->mech_ssf=0;
-    oparams->maxoutbuf = 0;
-    oparams->encode=NULL;
-    oparams->decode=NULL;
     if (! oparams->user) {
       oparams->user = params->utils->malloc(strlen(oparams->authid) + 1);
       if (! oparams->user)
@@ -814,6 +808,7 @@ static int client_continue_step (void *conn_context,
     }
 
     oparams->param_version = 0;
+    oparams->doneflag = 1;
 
     text->state = 99;
 
