@@ -1,32 +1,50 @@
 /* sample-client.c -- sample SASL client
  * Rob Earhart
  */
-/***********************************************************
-        Copyright 1999 by Carnegie Mellon University
-
-                      All Rights Reserved
-
-Permission to use, copy, modify, and distribute this software and its
-documentation for any purpose and without fee is hereby granted,
-provided that the above copyright notice appear in all copies and that
-both that copyright notice and this permission notice appear in
-supporting documentation, and that the name of Carnegie Mellon
-University not be used in advertising or publicity pertaining to
-distribution of the software without specific, written prior
-permission.
-
-CARNEGIE MELLON UNIVERSITY DISCLAIMS ALL WARRANTIES WITH REGARD TO
-THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND
-FITNESS, IN NO EVENT SHALL CARNEGIE MELLON UNIVERSITY BE LIABLE FOR
-ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
-WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
-ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT
-OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
-******************************************************************/
-
+/* 
+ * Copyright (c) 2000 Carnegie Mellon University.  All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ *
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer. 
+ *
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in
+ *    the documentation and/or other materials provided with the
+ *    distribution.
+ *
+ * 3. The name "Carnegie Mellon University" must not be used to
+ *    endorse or promote products derived from this software without
+ *    prior written permission. For permission or any other legal
+ *    details, please contact  
+ *      Office of Technology Transfer
+ *      Carnegie Mellon University
+ *      5000 Forbes Avenue
+ *      Pittsburgh, PA  15213-3890
+ *      (412) 268-4387, fax: (412) 268-7395
+ *      tech-transfer@andrew.cmu.edu
+ *
+ * 4. Redistributions of any form whatsoever must retain the following
+ *    acknowledgment:
+ *    "This product includes software developed by Computing Services
+ *     at Carnegie Mellon University (http://www.cmu.edu/computing/)."
+ *
+ * CARNEGIE MELLON UNIVERSITY DISCLAIMS ALL WARRANTIES WITH REGARD TO
+ * THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
+ * AND FITNESS, IN NO EVENT SHALL CARNEGIE MELLON UNIVERSITY BE LIABLE
+ * FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
+ * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
+ * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
+ * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ */
 #include <config.h>
 #include <limits.h>
 #include <stdio.h>
+#include <string.h>
+#include <stdlib.h>
 #ifdef WIN32
 # include <winsock.h>
 __declspec(dllimport) char *optarg;
@@ -37,9 +55,31 @@ __declspec(dllimport) int getsubopt(char **optionp, char * const *tokens, char *
 #endif /* WIN32 */
 #include <sasl.h>
 #include <saslutil.h>
+
+#ifdef macintosh
+#include <sioux.h>
+#include <parse_cmd_line.h>
+#define MAX_ARGC (100)
+int xxx_main(int argc, char *argv[]);
+int main(void)
+{
+	char *argv[MAX_ARGC];
+	int argc;
+	char line[400];
+	SIOUXSettings.asktosaveonclose = 0;
+	SIOUXSettings.showstatusline = 1;
+	argc=parse_cmd_line(MAX_ARGC,argv,sizeof(line),line);
+	return xxx_main(argc,argv);
+}
+#define main xxx_main
+#endif
+
 #ifdef HAVE_GETOPT_H
 #include <getopt.h>
 #endif
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
 
 #ifndef HAVE_GETSUBOPT
 int getsubopt(char **optionp, char * const *tokens, char **valuep);
@@ -395,6 +435,7 @@ samp_recv()
   if (result != SASL_OK)
     saslfail(result, "Decoding data from base64", NULL);
   buf[len] = '\0';
+  printf("recieved %d byte message\n",len);
   if (verbose) { printf("got '%s'\n", buf); }
   return len;
 }
@@ -756,9 +797,8 @@ main(int argc, char *argv[])
 			      &data, &len);
     if (result != SASL_OK && result != SASL_CONTINUE)
       saslfail(result, "Performing SASL negotiation", NULL);
-
-    puts("Sending response...");      
     if (data) {
+      puts("Sending response...");
       samp_send(data, len);
 #ifndef WIN32
       /* This free causes win32 to fail */
@@ -781,12 +821,33 @@ main(int argc, char *argv[])
     sasldebug(result, "realm", NULL);
   else
     printf("Realm: %s\n", data);
+#define CLIENT_MSG1 "client message 1"
+#define SERVER_MSG1 "srv message 1"
 
   result = sasl_getprop(conn, SASL_SSF, (void **)&ssf);
   if (result != SASL_OK)
     sasldebug(result, "ssf", NULL);
   else
     printf("SSF: %d\n", *ssf);
+ 
+ printf("Waiting for encoded message...\n");
+ len=samp_recv();
+ {
+ 	unsigned int recv_len;
+ 	char *recv_data;
+	result=sasl_decode(conn,buf,len,&recv_data,&recv_len);
+ 	if (result != SASL_OK)
+      saslfail(result, "sasl_encode", NULL);
+    printf("recieved decoded message '%s'\n",recv_data);
+    if(strcmp(recv_data,SERVER_MSG1)!=0)
+    	saslfail(1,"recive decoded server message",NULL);
+ }
+  result=sasl_encode(conn,CLIENT_MSG1,sizeof(CLIENT_MSG1),
+  	&data,&len);
+  if (result != SASL_OK)
+      saslfail(result, "sasl_encode", NULL);
+  printf("sending encrypted message '%s'\n",CLIENT_MSG1);
+  samp_send(data,len);
 
   return (EXIT_SUCCESS);
 }
