@@ -1,28 +1,45 @@
 /* sample-server.c -- sample SASL server
  * Rob Earhart
  */
-/***********************************************************
-        Copyright 1999 by Carnegie Mellon University
-
-                      All Rights Reserved
-
-Permission to use, copy, modify, and distribute this software and its
-documentation for any purpose and without fee is hereby granted,
-provided that the above copyright notice appear in all copies and that
-both that copyright notice and this permission notice appear in
-supporting documentation, and that the name of Carnegie Mellon
-University not be used in advertising or publicity pertaining to
-distribution of the software without specific, written prior
-permission.
-
-CARNEGIE MELLON UNIVERSITY DISCLAIMS ALL WARRANTIES WITH REGARD TO
-THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND
-FITNESS, IN NO EVENT SHALL CARNEGIE MELLON UNIVERSITY BE LIABLE FOR
-ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
-WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
-ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT
-OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
-******************************************************************/
+/* 
+ * Copyright (c) 2000 Carnegie Mellon University.  All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ *
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer. 
+ *
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in
+ *    the documentation and/or other materials provided with the
+ *    distribution.
+ *
+ * 3. The name "Carnegie Mellon University" must not be used to
+ *    endorse or promote products derived from this software without
+ *    prior written permission. For permission or any other legal
+ *    details, please contact  
+ *      Office of Technology Transfer
+ *      Carnegie Mellon University
+ *      5000 Forbes Avenue
+ *      Pittsburgh, PA  15213-3890
+ *      (412) 268-4387, fax: (412) 268-7395
+ *      tech-transfer@andrew.cmu.edu
+ *
+ * 4. Redistributions of any form whatsoever must retain the following
+ *    acknowledgment:
+ *    "This product includes software developed by Computing Services
+ *     at Carnegie Mellon University (http://www.cmu.edu/computing/)."
+ *
+ * CARNEGIE MELLON UNIVERSITY DISCLAIMS ALL WARRANTIES WITH REGARD TO
+ * THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
+ * AND FITNESS, IN NO EVENT SHALL CARNEGIE MELLON UNIVERSITY BE LIABLE
+ * FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
+ * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
+ * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
+ * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ */
 
 #include <config.h>
 #include <limits.h>
@@ -41,6 +58,9 @@ __declspec(dllimport) int getsubopt(char **optionp, char * const *tokens, char *
 #ifdef HAVE_GETOPT_H
 #include <getopt.h>
 #endif
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
 
 #ifndef HAVE_GETSUBOPT
 int getsubopt(char **optionp, char * const *tokens, char **valuep);
@@ -592,6 +612,32 @@ main(int argc, char *argv[])
     sasldebug(result, "ssf", NULL);
   else
     printf("SSF: %d\n", *ssf);
+#define CLIENT_MSG1 "client message 1"
+#define SERVER_MSG1 "srv message 1"
+  result=sasl_encode(conn,SERVER_MSG1,sizeof(SERVER_MSG1),
+  	&data,&len);
+  if (result != SASL_OK)
+      saslfail(result, "sasl_encode", NULL);
+  printf("sending encrypted message '%s'\n",SERVER_MSG1);
+  samp_send(data,len);
+  printf("Waiting for encrypted message...\n");
+  len=samp_recv();
+ {
+ 	unsigned int recv_len;
+ 	char *recv_data;
+	result=sasl_decode(conn,buf,len,&recv_data,&recv_len);
+ 	if (result != SASL_OK)
+      saslfail(result, "sasl_encode", NULL);
+    printf("recieved decoded message '%s'\n",recv_data);
+    if(strcmp(recv_data,CLIENT_MSG1)!=0)
+    	saslfail(1,"recive decoded server message",NULL);
+#ifndef WIN32
+	free(recv_data);
+#endif
+#ifndef WIN32
+  free(data);
+#endif
+ }
 
   return (EXIT_SUCCESS);
 }
